@@ -23,11 +23,11 @@ if (exists('doHypervolumeQuercusDemo')==TRUE)
   climate_rubra = extract(climatelayers_ss, data_rubra)
   
   # compute hypervolumes with auto-bandwidth for both species
-  hv_alba = hypervolume(climate_alba,quantile=0.0,reps=1000,bandwidth=estimate_bandwidth(climate_alba))
-  hv_rubra = hypervolume(climate_rubra,quantile=0.0,reps=1000,bandwidth=estimate_bandwidth(climate_rubra))
+  hv_alba = hypervolume(climate_alba,quantile=0.0,reps=1000,bandwidth=estimate_bandwidth(climate_alba),name='alba')
+  hv_rubra = hypervolume(climate_rubra,quantile=0.0,reps=1000,bandwidth=estimate_bandwidth(climate_rubra),name='rubra')
   
   # determine intersection and unique components of the overlap
-  hv_set = hypervolume_set(hv_alba, hv_rubra, reduction_factor = 0.5, check_memory=FALSE)
+  hv_set = hypervolume_set(hv_alba, hv_rubra, check_memory=FALSE)
   
   # put all the output volumes in one convenient place
   volumes <- c(Alba=get_volume(hv_alba), Rubra=get_volume(hv_rubra), get_volume(hv_set))
@@ -36,8 +36,8 @@ if (exists('doHypervolumeQuercusDemo')==TRUE)
   # get all the climate values
   climatevalues = data.frame(getValues(climatelayers_ss))
   
-  rubra_inout = hypervolume_inclusion_test(hv_rubra, climatevalues, reduction_factor=0.5)
-  alba_inout = hypervolume_inclusion_test(hv_alba, climatevalues, reduction_factor=0.5)
+  rubra_inout = hypervolume_inclusion_test(hv_rubra, climatevalues)
+  alba_inout = hypervolume_inclusion_test(hv_alba, climatevalues)
   
   # convert to rasters by setting values in rasters with same extent/resolution
   rubra_map = raster(climatelayers_ss[[1]]); values(rubra_map) <- rubra_inout
@@ -46,11 +46,8 @@ if (exists('doHypervolumeQuercusDemo')==TRUE)
   # then barplot of hypervolumes of each component
   barplot(volumes,horiz=TRUE,las=2,main="Hypervolume")
   
-  # plot 3d projection of 4d alba hypervolume 
-  plot(hv_alba, pair=FALSE, whichaxes=c(1,2,3), npmax=10000)
-  
   # then pairs plot of the set operations
-  plot(hv_set, npmax=5000)
+  plot(hv_set)
   
   # plot the geographic projections of the ranges
   par(mfrow=c(1,2))
